@@ -44,9 +44,9 @@ class Session:
         clabe: str = '',
         pool_size: Optional[int] = None,
     ):
-        priv_key = priv_key or os.getenv('PRIV_KEY', '')
+        priv_key = priv_key or os.getenv('STP_PRIVATE_LOCATION', '')
         priv_key_passphrase = priv_key_passphrase or os.getenv(
-            'PRIV_KEY_PASSPHRASE', ''
+            'STP_KEY_PASSPHRASE', ''
         )
         self.pkey = await gen_pkey(priv_key, priv_key_passphrase)
 
